@@ -12,7 +12,6 @@ from tdxapi.models.account_search import AccountSearch
 
 @attr.s
 class AccountManager(TdxManager, TdxCustomAttributeMixin):
-    __tdx_section__ = "Accounts"
     __tdx_component__ = Component.ACCOUNT
 
     @tdx_method("GET", "/api/accounts/{id}")
@@ -83,7 +82,7 @@ class AccountManager(TdxManager, TdxCustomAttributeMixin):
         helpers.save_model(account, self, force)
 
     @tdx_method("POST", "/api/accounts")
-    def _insert(self, account):
+    def _insert(self, account: Account) -> Account:
         """Creates a new account."""
         return self.dispatcher.send(
             self._insert.method,
@@ -95,7 +94,7 @@ class AccountManager(TdxManager, TdxCustomAttributeMixin):
         )
 
     @tdx_method("PUT", "/api/accounts/{id}")
-    def _update(self, account):
+    def _update(self, account: Account) -> Account:
         """Edits the account specified by the account ID."""
         return self.dispatcher.send(
             self._update.method,
