@@ -9,27 +9,25 @@ from tdxapi.models.custom_attribute_choice import CustomAttributeChoice
 
 @attr.s
 class CustomAttributeChoiceManager(TdxManager):
-    __tdx_section__ = "Attributes"
-
-    def get(self, attribute_id: int, attribute_choice_id: int) -> CustomAttributeChoice:
+    def get(self, attribute_choice_id: int, attribute_id: int) -> CustomAttributeChoice:
         """Gets a CustomAttributeChoice."""
-        for attribute_choice in self.all(attribute_id):
+        for attribute_choice in self.get_by_attribute(attribute_id):
             if attribute_choice.id == attribute_choice_id:
                 return attribute_choice
 
     @tdx_method("GET", "/api/attributes/{id}/choices")
-    def all(self, attribute_id: int) -> List[CustomAttributeChoice]:
+    def get_by_attribute(self, attribute_id: int) -> List[CustomAttributeChoice]:
         """Gets the choices for the specified custom attribute."""
         return self.dispatcher.send(
-            self.all.method,
-            self.all.url.format(id=attribute_id),
+            self.get_by_attribute.method,
+            self.get_by_attribute.url.format(id=attribute_id),
             rclass=CustomAttributeChoice,
             rlist=True,
             rpartial=True,
         )
 
     @tdx_method("DELETE", "/api/attributes/{id}/choices/{choiceId}")
-    def delete(self, attribute_id: int, attribute_choice_id: int) -> None:
+    def delete(self, attribute_choice_id: int, attribute_id: int) -> None:
         """Removes the specified choice from the custom attribute."""
         self.dispatcher.send(
             self.delete.method,
@@ -58,7 +56,9 @@ class CustomAttributeChoiceManager(TdxManager):
         helpers.update_model(attribute_choice, updated_model)
 
     @tdx_method("POST", "/api/attributes/{id}/choices")
-    def _insert(self, attribute_choice, attribute_id):
+    def _insert(
+        self, attribute_choice: CustomAttributeChoice, attribute_id: int
+    ) -> CustomAttributeChoice:
         """Adds a new choice to the specified custom attribute."""
         return self.dispatcher.send(
             self._insert.method,
@@ -70,7 +70,9 @@ class CustomAttributeChoiceManager(TdxManager):
         )
 
     @tdx_method("PUT", "/api/attributes/{id}/choices/{choiceId}")
-    def _update(self, attribute_choice, attribute_id):
+    def _update(
+        self, attribute_choice: CustomAttributeChoice, attribute_id: int
+    ) -> CustomAttributeChoice:
         """Edits an existing choice associated with the specified custom attribute."""
         return self.dispatcher.send(
             self._update.method,
