@@ -12,7 +12,6 @@ from tdxapi.models.vendor_search import VendorSearch
 
 @attr.s
 class VendorManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
-    __tdx_section__ = "Vendors"
     __tdx_component__ = Component.VENDOR
 
     @tdx_method("GET", "/api/{appId}/assets/vendors/{id}")
@@ -87,7 +86,7 @@ class VendorManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         helpers.save_model(vendor, self, force)
 
     @tdx_method("POST", "/api/{appId}/assets/vendors")
-    def _insert(self, vendor):
+    def _insert(self, vendor: Vendor) -> Vendor:
         """Creates a new vendor."""
         return self.dispatcher.send(
             self._insert.method,
@@ -99,7 +98,7 @@ class VendorManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         )
 
     @tdx_method("PUT", "/api/{appId}/assets/vendors/{id}")
-    def _update(self, vendor):
+    def _update(self, vendor: Vendor) -> Vendor:
         """Edits the vendor specified by the vendor ID."""
         return self.dispatcher.send(
             self._update.method,
